==> jira-projects-plugin-4.3.2.jar: static/components/subnavigator/views/Trigger-test.js <==
AJS.test.require("com.atlassian.jira.jira-projects-plugin:subnavigator-test", function() {
    "use strict";

    var ITEM_1 = { id: "item1", label: "Item 1", description: "Item 1"};
    var ITEM_2 = { id: "item2", label: "Item 2", description: "Item 2" };
    var ITEMS = [[ITEM_1], [ITEM_2]];

    var ID = "id";

    module("JIRA.Projects.Subnavigator.View.Trigger", {
        setup: function() {
            this.$el = AJS.$("<div/>");
            this.model = new JIRA.Projects.Subnavigator.Entities.Items({itemGroups: ITEMS});
            this.view = new JIRA.Projects.Subnavigator.Views.Trigger({
                el: this.$el,
                model: this.model,
                id: ID
            });
        }
    });

    test("Uses the label of the selected item to render the template", function() {
        this.model.selectItem(ITEM_2.id);

        var viewData = this.view.serializeData();

        equal(viewData.label, ITEM_2.label);
    });

    test("Renders as a button when there is more than one item", function() {
        this.model.selectItem(ITEM_1.id);

        var viewData = this.view.serializeData();

        strictEqual(viewData.renderAsButton, true);
    });

    test("Renders as text when there is one item", function() {
        this.model.set({itemGroups: [ITEM_1]});
        this.model.selectItem(ITEM_1.id);

        var viewData = this.view.serializeData();

        strictEqual(viewData.renderAsButton, false);
    });

    test("Uses the given id as a suffix when rendering the template", function() {
        this.model.set({itemGroups: [ITEM_1]});
        this.model.selectItem(ITEM_1.id);

        this.view.render();

        ok(this.$el.find("#subnav-trigger-" + ID).length === 1);
    });
});

==> jira-projects-plugin-6.0.5.jar: static/components/subnavigator/views/Trigger-test.js <==
AJS.test.require("com.atlassian.jira.jira-projects-plugin:subnavigator-test", function() {
    "use strict";

    var jQuery = require("jquery");
    var Items = require("jira/projects/components/subnavigator/entities/items");
    var Trigger = require("jira/projects/components/subnavigator/views/trigger");

    var ITEM_1 = { id: "item1", label: "Item 1", description: "Item 1"};
    var ITEM_2 = { id: "item2", label: "Item 2", description: "Item 2" };
    var ITEMS = [[ITEM_1], [ITEM_2]];

    var ID = "id";

    module("jira/projects/components/subnavigator/views/trigger", {
        setup: function() {
            this.$el = jQuery("<div/>");
            this.model = new Items({itemGroups: ITEMS});
            this.view = new Trigger({
                el: this.$el,
                model: this.model,
                id: ID
            });
        }
    });

    test("Uses the label of the selected item to render the template", function() {
        this.model.selectItem(ITEM_2.id);

        var viewData = this.view.serializeData();

        equal(viewData.label, ITEM_2.label);
    });

    test("Renders as a button when there is more than one item", function() {
        this.model.selectItem(ITEM_1.id);

        var viewData = this.view.serializeData();

        strictEqual(viewData.renderAsButton, true);
    });

    test("Renders as text when there is one item", function() {
        this.model.set({itemGroups: [ITEM_1]});
        this.model.selectItem(ITEM_1.id);

        var viewData = this.view.serializeData();

        strictEqual(viewData.renderAsButton, false);
    });

    test("Uses the given id as a suffix when rendering the template", function() {
        this.model.set({itemGroups: [ITEM_1]});
        this.model.selectItem(ITEM_1.id);

        this.view.render();

        ok(this.$el.find("#subnav-trigger-" + ID).length === 1);
    });
});
